==> 0.9.1-alpha.tar.gz: lib/beagle.dart <==
/*
 * Copyright 2020 ZUP IT SERVICOS EM TECNOLOGIA E INOVACAO SA
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

library beagle;

export 'package:beagle/src/action/beagle_alert.dart';
export 'package:beagle/src/action/beagle_open_external_url.dart';
export 'package:beagle/src/action/beagle_open_native_route.dart';

export 'package:beagle/src/components/beagle_undefined_widget.dart';

export 'package:beagle/src/default/empty/default_empty_design_system.dart';
export 'package:beagle/src/default/empty/default_empty_logger.dart';
export 'package:beagle/src/default/default_actions.dart';
export 'package:beagle/src/default/default_http_client.dart';
export 'package:beagle/src/default/default_image_downloader.dart';
export 'package:beagle/src/default/default_logger.dart';
export 'package:beagle/src/default/default_storage.dart';
export 'package:beagle/src/default/url_builder.dart';

export 'package:beagle/src/interface/beagle_image_downloader.dart';
export 'package:beagle/src/interface/beagle_navigator.dart';
export 'package:beagle/src/interface/beagle_service.dart';
export 'package:beagle/src/interface/beagle_view.dart';
export 'package:beagle/src/interface/global_context.dart';
export 'package:beagle/src/interface/http_client.dart';
export 'package:beagle/src/interface/navigation_controller.dart';
export 'package:beagle/src/interface/renderer.dart';
export 'package:beagle/src/interface/storage.dart';
export 'package:beagle/src/interface/types.dart';

export 'package:beagle/src/logger/beagle_logger.dart';

export 'package:beagle/src/model/beagle_action.dart';
export 'package:beagle/src/model/beagle_button_style.dart';
export 'package:beagle/src/model/beagle_environment.dart';
export 'package:beagle/src/model/beagle_style.dart';
export 'package:beagle/src/model/beagle_ui_element.dart';
export 'package:beagle/src/model/response.dart';
export 'package:beagle/src/model/route.dart';
export 'package:beagle/src/model/tree_update_mode.dart';

export 'package:beagle/src/networking/beagle_http_method.dart';
export 'package:beagle/src/networking/beagle_network_options.dart';
export 'package:beagle/src/networking/beagle_network_strategy.dart';
export 'package:beagle/src/networking/beagle_request.dart';
export 'package:beagle/src/networking/beagle_screen_request.dart';

export 'package:beagle/src/setup/beagle_design_system.dart';

export 'package:beagle/src/style/style_builder.dart';

export 'package:beagle/src/utils/color.dart';
export 'package:beagle/src/utils/enum.dart';

export 'package:beagle/src/beagle_sdk.dart';
export 'package:beagle/src/beagle_widget.dart';

export 'package:beagle/src/service_locator.dart' show beagleServiceLocator;

==> 0.9.4-alpha.tar.gz: lib/beagle.dart <==
/*
 * Copyright 2020 ZUP IT SERVICOS EM TECNOLOGIA E INOVACAO SA
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

library beagle;

export 'package:beagle/src/action/beagle_alert.dart';
export 'package:beagle/src/action/beagle_confirm.dart';
export 'package:beagle/src/action/beagle_open_external_url.dart';
export 'package:beagle/src/action/beagle_open_native_route.dart';

export 'package:beagle/src/components/beagle_undefined_widget.dart';

export 'package:beagle/src/default/empty/default_empty_design_system.dart';
export 'package:beagle/src/default/empty/default_empty_logger.dart';
export 'package:beagle/src/default/default_http_client.dart';
export 'package:beagle/src/default/default_image_downloader.dart';
export 'package:beagle/src/default/default_logger.dart';
export 'package:beagle/src/default/url_builder.dart';
export 'package:beagle/src/navigation/root_navigator.dart';
export 'package:beagle/src/navigation/stack_navigator.dart';
export 'package:beagle/src/default/default_view_client.dart';
export 'package:beagle/src/default/default_navigation_controller.dart';

export 'package:beagle/src/interface/beagle_image_downloader.dart';
export 'package:beagle/src/interface/beagle_navigator.dart';
export 'package:beagle/src/interface/beagle_service.dart';
export 'package:beagle/src/interface/beagle_view.dart';
export 'package:beagle/src/interface/global_context.dart';
export 'package:beagle/src/interface/http_client.dart';
export 'package:beagle/src/interface/navigation_controller.dart';
export 'package:beagle/src/interface/renderer.dart';
export 'package:beagle/src/interface/types.dart';
export 'package:beagle/src/interface/view_client.dart';

export 'package:beagle/src/logger/beagle_logger.dart';

export 'package:beagle/src/model/beagle_action.dart';
export 'package:beagle/src/model/beagle_button_style.dart';
export 'package:beagle/src/model/beagle_environment.dart';
export 'package:beagle/src/model/beagle_navigation_bar_style.dart';
export 'package:beagle/src/model/beagle_style.dart';
export 'package:beagle/src/model/beagle_ui_element.dart';
export 'package:beagle/src/model/response.dart';
export 'package:beagle/src/model/route.dart';
export 'package:beagle/src/model/tree_update_mode.dart';

export 'package:beagle/src/networking/beagle_http_method.dart';
export 'package:beagle/src/networking/beagle_network_options.dart';
export 'package:beagle/src/networking/beagle_request.dart';

export 'package:beagle/src/setup/beagle_design_system.dart';

export 'package:beagle/src/style/beagle_yoga_factory.dart';

export 'package:beagle/src/utils/color.dart';
export 'package:beagle/src/utils/enum.dart';

export 'package:beagle/src/beagle_sdk.dart';
export 'package:beagle/src/beagle_widget.dart';
export 'package:beagle/src/beagle_flex_widget.dart';

export 'package:beagle/src/service_locator.dart' show beagleServiceLocator;
export 'package:beagle/src/analytics/analytics_config.dart';
export 'package:beagle/src/analytics/analytics_provider.dart';
export 'package:beagle/src/analytics/analytics_record.dart';

export 'package:beagle/src/model/beagle_template_manager.dart';
export 'package:beagle/src/model/beagle_ui_element.dart';
export 'package:beagle/src/model/beagle_data_context.dart';

export 'package:beagle/src/beagle_metadata_widget.dart';
export 'package:beagle/src/model/beagle_metadata.dart';
